StreamBlocTransformers<Event extends Object?, State extends Object?> class abstract

An interface that allows transforming its events and following transitions

Implementers

Constructors

StreamBlocTransformers()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
transformEvents(Stream<Event> events, TransitionFunction<Event, State> transitionFn) Stream<Transition<Event, State>>
Transforms the events stream along with a transitionFn function into a Stream<Transition>. Events that should be processed by StreamBlocMapper.mapEventToStates need to be passed to transitionFn. By default asyncExpand is used to ensure all events are processed in the order in which they are received. You can override transformEvents for advanced usage in order to manipulate the frequency and specificity with which StreamBlocMapper.mapEventToStates is called as well as which events are processed.
transformSourceEvents(Stream<Event> events) Stream<Event>
Transforms the Stream<Event> into a new Stream<Event>. By default transformSourceEvents returns the incoming Stream<Event>. You can override transformSourceEvents in order to manipulate the frequency and specificity at which incoming events are delivered.
transformTransitions(Stream<Transition<Event, State>> transitions) Stream<Transition<Event, State>>
Transforms the Stream<Transition> into a new Stream<Transition>. By default transformTransitions returns the incoming Stream<Transition>. You can override transformTransitions for advanced usage in order to manipulate the frequency and specificity at which transitions (state changes) occur.

Operators

operator ==(Object other) bool
The equality operator.
inherited