StreamBlocTransformers<Event extends Object?, State extends Object?> class
abstract
An interface that allows transforming its events and following transitions
- Implementers
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
transformEvents(
Stream< Event> events, TransitionFunction<Event, State> transitionFn) → Stream<Transition< Event, State> > -
Transforms the
eventsstream along with atransitionFnfunction into aStream<Transition>. Events that should be processed by StreamBlocMapper.mapEventToStates need to be passed totransitionFn. By defaultasyncExpandis used to ensure alleventsare processed in the order in which they are received. You can override transformEvents for advanced usage in order to manipulate the frequency and specificity with which StreamBlocMapper.mapEventToStates is called as well as whicheventsare processed. -
transformSourceEvents(
Stream< Event> events) → Stream<Event> -
Transforms the
Stream<Event>into a newStream<Event>. By default transformSourceEvents returns the incomingStream<Event>. You can override transformSourceEvents in order to manipulate the frequency and specificity at which incomingeventsare delivered. -
transformTransitions(
Stream< Transition< transitions) → Stream<Event, State> >Transition< Event, State> > -
Transforms the
Stream<Transition>into a newStream<Transition>. By default transformTransitions returns the incomingStream<Transition>. You can override transformTransitions for advanced usage in order to manipulate the frequency and specificity at whichtransitions(state changes) occur.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited